{% extends "customer/emails/base.html" %}
{% load i18n %}

{% block body %}{% autoescape off %}
<p>
    {% blocktrans with name=site.name %}You're receiving this e-mail because you requested a password reset for your user account at {{ name }}.{% endblocktrans %}
</p>

<p>{% trans "Please go to the following page and choose a new password:" %}</p>
{{ reset_url }}

{% endautoescape %}{% endblock %}
