{% extends "customer/baseaccountpage.html" %}
{% load i18n %}

{% block tabcontent %}
    <form id="change_password_form" action="." method="post">
        {% csrf_token %}
        {% include 'partials/form.html' %}
    </form>
{% endblock tabcontent %}
