{% extends "error.html" %}
{% load i18n %}

{% block title %}
{% trans 'Page not found' %} | {{ block.super }}
{% endblock %}

{% block error_heading %}
{% trans "Page not found!" %}
{% endblock %}

{% block error_message %}
<p>{% trans "We're sorry but the page you are looking for can't be found." %}</p>
{% endblock %}
