{% load currency_filters %}
{% load i18n %}
{% load purchase_info_tags %}
{% load cache %}

{% purchase_info_for_product request product as session %}

{% if session.price.exists %}
    {% if session.price.is_tax_known %}
        <h2 class="price_color">{{ session.price.incl_tax|currency:session.price.currency }}</h2>
    {% else %}
        <h2 class="price_color">{{ session.price.excl_tax|currency:session.price.currency }}</h2>
    {% endif %}
{% else %}
    <h2 class="price_color"></h2>
{% endif %}
<p class="{{ session.availability.code }} availability">
    <i class="icon-{% if session.availability.is_available_to_buy %}ok{% else %}remove{% endif %}"></i>
    {% if verbose %}
        {{ session.availability.message }}
    {% else %}
        {{ session.availability.short_message }}
    {% endif %}
</p>
