{% extends 'dashboard/promotions/form.html' %}
{% load i18n %}

{% block inlines %}
<h2>{% trans "Products" %}</h2>
{{ product_formset.management_form }}
{% for form in product_formset %}
    {% include "partials/form_fields.html" with form=form %}
{% endfor %}
{% endblock %}
