{% extends "customer/baseaccountpage.html" %}
{% load i18n %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{{ homepage_url }}">{% trans 'Home' %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'customer:summary' %}">{% trans 'Account' %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'customer:wishlists-list' %}">{% trans 'Wish Lists' %}</a>
            <span class="divider">/</span>
        </li>
        <li class="active">
            {% if wishlist %}
                {{ wishlist.name }}
            {% else %}
                {% trans "Create" %}
            {% endif %}
        </li>
    </ul>
{% endblock %}

{% block tabcontent %}
    <form action="." method="post" data-behaviours="lock">
        {% csrf_token %}
        {% if not wishlist %}
            <p>{% trans "What should your new wish list be called?" %}</p>
        {% endif %}
        {% include "partials/form_fields.html" %}
        {% if product %}
            <p>
                {% blocktrans with title=product.get_title %}
                    After your wishlist is created, <strong>{{ title }}</strong> will be added.
                {% endblocktrans %}
            </p>
        {% endif %}
        <div class="form-actions">
            <button class="btn btn-large btn-primary" type="submit">{% trans "Save" %}</button>
            {% trans "or" %} <a href="#" onclick="history.go(-1);return false" >{% trans "cancel" %}</a>.
        </div>
    </form>
{% endblock tabcontent %}
