{% extends 'dashboard/layout.html' %}

{% load i18n %}

{% block body_class %}{{ block.super }} create-page users{% endblock %}

{% block title %}
    {% blocktrans with id=alert.id %}Alert #{{ id }}{% endblocktrans %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'dashboard:user-alert-list' %}">{% trans "Product alerts" %}</a>
            <span class="divider">/</span>
        </li>
        <li class="active">{% blocktrans with id=alert.id %}Alert #{{ id }}{% endblocktrans %}</li>
    </ul>
{% endblock %}

{% block headertext %}
    {% blocktrans with id=alert.id %}Delete alert #{{ id }}?{% endblocktrans %}
{% endblock %}

{% block dashboard_content %}
    <div class="table-header">
        <h2>{% blocktrans with id=alert.id %}Product alert #{{ id }}{% endblocktrans %}</h2>
    </div>
    <div class="well">
        {% include 'dashboard/users/alerts/partials/alert.html' %}
        <form action="." method="post" >
            {% csrf_token %}
            <div class="form-actions">
                <p>{% trans "Are you sure that you want to delete this alert?" %}</p>
                <button type='submit' class="btn btn-large btn-danger">{% trans "Delete" %}</button> {% trans "or" %}
                <a href="{% url 'dashboard:user-alert-list' %}">{% trans "cancel" %}</a>
            </div>
        </form>
    </div>
{% endblock dashboard_content %}
