{% extends "dashboard/layout.html" %}
{% load category_tags %}
{% load i18n %}

{% block body_class %}{{ block.super }} create-page partner{% endblock %}

{% block title %}
    {{ title }} | {{ partner.name }} | {% trans "Partner management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'dashboard:partner-list' %}">{% trans "Partner management" %}</a>
            <span class="divider">/</span>
        </li>
        {% if partner %}
            <li>
                <a href="{% url 'dashboard:partner-manage' pk=partner.id %}">{{ partner.name }}</a>
                <span class="divider">/</span>
            </li>
        {% endif %}
        <li class="active">{{ title }}</li>
    </ul>
{% endblock %}

{% block headertext %}{{ title }}{% endblock %}

{% block dashboard_content %}
    {% include "partials/form.html" %}
{% endblock dashboard_content %}
