{% load i18n %}

<dt>{{ name }}</dt>
{% for item in items %}
<dd>
    {% with item_count=item.count %}
        {% if item.selected %}
            <strong>{{ item.name }} ({{ item_count }})</strong>
            <small><a href="{{ item.deselect_url }}">{% trans "Remove" %}</a></small>
        {% else %}
                {% if item_count %}
                    <a href="{{ item.select_url }}">{{ item.name }}</a> ({{ item_count }})
                {% else %}
                    {{ item.name }} (0)
                {% endif %}
        {% endif %}
    {% endwith %}
</dd>
{% endfor %}

