{% load currency_filters %}
{% load i18n %}

<div class="basket-mini pull-right hidden-phone">
    <strong>{% trans "Basket total:" %}</strong>
    {% if request.basket.is_tax_known %}
        {{ request.basket.total_incl_tax|currency:request.basket.currency }}
    {% else %}
        {{ request.basket.total_excl_tax|currency:request.basket.currency }}
    {% endif %}

    <span class="btn-group">
        <a class="btn" href="{% url 'basket:summary' %}">{% trans "View basket" %}</a>
        <button class="btn dropdown-toggle" data-toggle="dropdown">
            <span class="caret"></span>
        </button>
        <ul class="dropdown-menu pull-right">
            <li>{% include "basket/partials/basket_quick.html" %}</li>
        </ul>
    </span>
</div>