{% extends "customer/baseaccountpage.html" %}
{% load i18n %}

{% block tabcontent %}
	<form id="profile_form" action="." method="post">
		{% csrf_token %}
		{% include 'partials/form.html' %}
	</form>
{% endblock tabcontent %}
