{% extends "catalogue/detail.html" %}
{% load i18n %}

{% block product_review %}
    <div id="addreview" class="review_add">
        <form id="add_review_form" method="post" action="./#addreview">
            <fieldset>
                <legend>{% trans "Leave a product review" %}</legend>
                {% csrf_token %}
                {% include "partials/form_fields.html" with form=form %}
                <button type="submit"  class="btn btn-primary">{% trans "Submit" %}</button>
                {% trans "or" %}
                <a href="{{ product.get_absolute_url }}" >{% trans "cancel" %}</a>
            </fieldset>
        </form>
    </div>
{% endblock %}
