// Modifications / additons to wells
.well {
	.clearfix();
}
.well-success {
	background-color: @successBackground;
	border-color: @successBorder;
}
.well-info {
	background-color: @infoBackground;
	border-color: @infoBorder;
}
.well-blank {
	background-color: @white;
	border-color: rgba(0,0,0,.1);
}