{% load i18n %}
<footer class="footer container-fluid">
    {% block footer %}
        {% comment %}
            Could be used for displaying links to privacy policy, terms of service, etc.
            We have a CSS class defined:
                <ul class="footer_links inline">
                    ...
                </ul>
         {% endcomment %}
    {% endblock %}
</footer>