{% extends 'layout.html' %}
{% load i18n %}

{% block title %}{% trans 'Password reset successful' %} | {{ block.super }}{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{{ homepage_url }}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans 'Password reset sent' %}</li>
</ul>
{% endblock %}

{% block content %}

    <div class="sub-header">
        <h2>{% trans "Password reset successful" %}</h2>
    </div>

    <p>{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>

{% endblock %}
