// OSCAR CHECKOUT UNIQUE STYLES
// -----------

//Set Width of all quantity fields
input[type="text"][id*="quantity"], input[type="number"][id*="quantity"] {
    width:30px;
}
// Quantity on the basket
.checkout-quantity {
    input {
        margin-right: 2px;
        margin-bottom:0px;
    }
}

// Basket items like table headers
.basket-title {
    clear:both;
    border-bottom:1px solid lighten(@grayLight, 30%);
    padding:0 10px;
    h4 {
        margin:0;
    }
}

// Basket items
.basket-items {
    border-bottom:1px solid lighten(@grayLight, 30%);
    padding:10px;
    &:nth-child(even) {
        background:lighten(@grayLighter, 4%);
    }
    img {
        margin-left:auto;
        margin-right:auto;
    }
    .price_color {
        .h4();
        font-weight:bold;
    }
}

// Descriptions next to shipping prices - basket totals table
#basket_totals {
	th small {
		font-weight: normal;
	}
}

// Table background for totals
.total {
    background-color:#FDF5D9!important;
}


// Choosing a shipping address
.choose-block {
    ul {
        .clearfix();
    }
    .well {
        position:relative;
        min-height:240px;
        form {
        margin-bottom:0;
        }
    }
    address {
        margin-bottom:0;
        span:first-child {
        display:block;
        font-weight:bold;
        margin-bottom:@baseLineHeight / 2;
        }
    }
    .btn-primary,
    .btn-success {
        position:absolute;
        bottom: @gridGutterWidth;
        left: @gridGutterWidth;
    }
    .btn-remove-address {
        position:absolute;
        top: @gridGutterWidth;
        right: @gridGutterWidth;
    }
}

// Checkout navigation - uses navbar
.nav-checkout {
    text-align:center;
    &.navbar .nav {
        margin:0;
    }
    .active {
        .navbar-text {
        color:#fff;
        }
    }
}
