{% extends 'dashboard/layout.html' %}
{% load i18n %}

{% block body_class %}{{ block.super }} create-page{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
            <span class="divider">/</span>
        </li>
        <li>
        <a href="{% if parent %}{% url 'dashboard:catalogue-category-detail-list' pk=parent.pk %}{% else %}{% url 'dashboard:catalogue-category-list' %}{% endif %}">{% trans "Categories" %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans "Delete category?" %}</li>
</ul>
{% endblock %}

{% block headertext %}
    {% trans "Delete category?" %}
{% endblock %}

{% block dashboard_content %}
    <div class="table-header">
        <h2>{% trans "Delete category" %}</h2>
    </div>
    <form action="." method="post" class="well">
        {% csrf_token %}
        {{ form }}
        {% blocktrans with name=object.name %}
            <p>Delete category <strong>{{ name }}</strong> - are you sure?</p>
        {% endblocktrans %}
        <div class="form-actions">
            <button type="submit" class="btn btn-danger">{% trans "Delete" %}</button>
        {% trans "or" %} <a href="{% if parent %}{% url 'dashboard:catalogue-category-detail-list' pk=parent.pk %}{% else %}{% url 'dashboard:catalogue-category-list' %}{% endif %}">{% trans "cancel" %}</a>
    </div>
</form>
{% endblock %}
