@import url("//fonts.googleapis.com/css?family=Open+Sans:700,300");
.clearfix {
  *zoom: 1;
}
.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
}
.clearfix:after {
  clear: both;
}
.hide-text {
  overflow: hidden;
  text-indent: 100%;
  white-space: nowrap;
}
.input-block-level {
  display: block;
  width: 100%;
  min-height: 28px;
  /* Make inputs at least the height of their button counterpart */

  /* Makes inputs behave like true block-level elements */

  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
/*!
 *  Font Awesome 3.2.1
 *  the iconic font designed for Bootstrap
 *  ------------------------------------------------------------------------------
 *  The full suite of pictographic icons, examples, and documentation can be
 *  found at http://fontawesome.io.  Stay up to date on Twitter at
 *  http://twitter.com/fontawesome.
 *
 *  License
 *  ------------------------------------------------------------------------------
 *  - The Font Awesome font is licensed under SIL OFL 1.1 -
 *    http://scripts.sil.org/OFL
 *  - Font Awesome CSS, LESS, and SASS files are licensed under MIT License -
 *    http://opensource.org/licenses/mit-license.html
 *  - Font Awesome documentation licensed under CC BY 3.0 -
 *    http://creativecommons.org/licenses/by/3.0/
 *  - Attribution is no longer required in Font Awesome 3.0, but much appreciated:
 *    "Font Awesome by Dave Gandy - http://fontawesome.io"
 *
 *  Author - Dave Gandy
 *  ------------------------------------------------------------------------------
 *  Email: dave@fontawesome.io
 *  Twitter: http://twitter.com/davegandy
 *  Work: Lead Product Designer @ Kyruus - http://kyruus.com
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url('../fonts/fontawesome-webfont.eot?v=3.2.1');
  src: url('../fonts/fontawesome-webfont.eot?#iefix&v=3.2.1') format('embedded-opentype'), url('../fonts/fontawesome-webfont.woff?v=3.2.1') format('woff'), url('../fonts/fontawesome-webfont.ttf?v=3.2.1') format('truetype'), url('../fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1') format('svg');
  font-weight: normal;
  font-style: normal;
}
/* FONT AWESOME CORE
 * -------------------------- */
[class^="icon-"],
[class*=" icon-"] {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
  -webkit-font-smoothing: antialiased;
  *margin-right: .3em;
}
[class^="icon-"]:before,
[class*=" icon-"]:before {
  text-decoration: inherit;
  display: inline-block;
  speak: none;
}
/* makes the font 33% larger relative to the icon container */
.icon-large:before {
  vertical-align: -10%;
  font-size: 1.3333333333333333em;
}
/* makes sure icons active on rollover in links */
a [class^="icon-"],
a [class*=" icon-"] {
  display: inline;
}
/* increased font size for icon-large */
[class^="icon-"].icon-fixed-width,
[class*=" icon-"].icon-fixed-width {
  display: inline-block;
  width: 1.1428571428571428em;
  text-align: right;
  padding-right: 0.2857142857142857em;
}
[class^="icon-"].icon-fixed-width.icon-large,
[class*=" icon-"].icon-fixed-width.icon-large {
  width: 1.4285714285714286em;
}
.icons-ul {
  margin-left: 2.142857142857143em;
  list-style-type: none;
}
.icons-ul > li {
  position: relative;
}
.icons-ul .icon-li {
  position: absolute;
  left: -2.142857142857143em;
  width: 2.142857142857143em;
  text-align: center;
  line-height: inherit;
}
[class^="icon-"].hide,
[class*=" icon-"].hide {
  display: none;
}
.icon-muted {
  color: #eeeeee;
}
.icon-light {
  color: #ffffff;
}
.icon-dark {
  color: #333333;
}
.icon-border {
  border: solid 1px #eeeeee;
  padding: .2em .25em .15em;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.icon-2x {
  font-size: 2em;
}
.icon-2x.icon-border {
  border-width: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.icon-3x {
  font-size: 3em;
}
.icon-3x.icon-border {
  border-width: 3px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.icon-4x {
  font-size: 4em;
}
.icon-4x.icon-border {
  border-width: 4px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.icon-5x {
  font-size: 5em;
}
.icon-5x.icon-border {
  border-width: 5px;
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  border-radius: 7px;
}
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
[class^="icon-"].pull-left,
[class*=" icon-"].pull-left {
  margin-right: .3em;
}
[class^="icon-"].pull-right,
[class*=" icon-"].pull-right {
  margin-left: .3em;
}
/* BOOTSTRAP SPECIFIC CLASSES
 * -------------------------- */
/* Bootstrap 2.0 sprites.less reset */
[class^="icon-"],
[class*=" icon-"] {
  display: inline;
  width: auto;
  height: auto;
  line-height: normal;
  vertical-align: baseline;
  background-image: none;
  background-position: 0% 0%;
  background-repeat: repeat;
  margin-top: 0;
}
/* more sprites.less reset */
.icon-white,
.nav-pills > .active > a > [class^="icon-"],
.nav-pills > .active > a > [class*=" icon-"],
.nav-list > .active > a > [class^="icon-"],
.nav-list > .active > a > [class*=" icon-"],
.navbar-inverse .nav > .active > a > [class^="icon-"],
.navbar-inverse .nav > .active > a > [class*=" icon-"],
.dropdown-menu > li > a:hover > [class^="icon-"],
.dropdown-menu > li > a:hover > [class*=" icon-"],
.dropdown-menu > .active > a > [class^="icon-"],
.dropdown-menu > .active > a > [class*=" icon-"],
.dropdown-submenu:hover > a > [class^="icon-"],
.dropdown-submenu:hover > a > [class*=" icon-"] {
  background-image: none;
}
/* keeps Bootstrap styles with and without icons the same */
.btn [class^="icon-"].icon-large,
.nav [class^="icon-"].icon-large,
.btn [class*=" icon-"].icon-large,
.nav [class*=" icon-"].icon-large {
  line-height: .9em;
}
.btn [class^="icon-"].icon-spin,
.nav [class^="icon-"].icon-spin,
.btn [class*=" icon-"].icon-spin,
.nav [class*=" icon-"].icon-spin {
  display: inline-block;
}
.nav-tabs [class^="icon-"],
.nav-pills [class^="icon-"],
.nav-tabs [class*=" icon-"],
.nav-pills [class*=" icon-"],
.nav-tabs [class^="icon-"].icon-large,
.nav-pills [class^="icon-"].icon-large,
.nav-tabs [class*=" icon-"].icon-large,
.nav-pills [class*=" icon-"].icon-large {
  line-height: .9em;
}
.btn [class^="icon-"].pull-left.icon-2x,
.btn [class*=" icon-"].pull-left.icon-2x,
.btn [class^="icon-"].pull-right.icon-2x,
.btn [class*=" icon-"].pull-right.icon-2x {
  margin-top: .18em;
}
.btn [class^="icon-"].icon-spin.icon-large,
.btn [class*=" icon-"].icon-spin.icon-large {
  line-height: .8em;
}
.btn.btn-small [class^="icon-"].pull-left.icon-2x,
.btn.btn-small [class*=" icon-"].pull-left.icon-2x,
.btn.btn-small [class^="icon-"].pull-right.icon-2x,
.btn.btn-small [class*=" icon-"].pull-right.icon-2x {
  margin-top: .25em;
}
.btn.btn-large [class^="icon-"],
.btn.btn-large [class*=" icon-"] {
  margin-top: 0;
}
.btn.btn-large [class^="icon-"].pull-left.icon-2x,
.btn.btn-large [class*=" icon-"].pull-left.icon-2x,
.btn.btn-large [class^="icon-"].pull-right.icon-2x,
.btn.btn-large [class*=" icon-"].pull-right.icon-2x {
  margin-top: .05em;
}
.btn.btn-large [class^="icon-"].pull-left.icon-2x,
.btn.btn-large [class*=" icon-"].pull-left.icon-2x {
  margin-right: .2em;
}
.btn.btn-large [class^="icon-"].pull-right.icon-2x,
.btn.btn-large [class*=" icon-"].pull-right.icon-2x {
  margin-left: .2em;
}
/* Fixes alignment in nav lists */
.nav-list [class^="icon-"],
.nav-list [class*=" icon-"] {
  line-height: inherit;
}
/* EXTRAS
 * -------------------------- */
/* Stacked and layered icon */
.icon-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: -35%;
}
.icon-stack [class^="icon-"],
.icon-stack [class*=" icon-"] {
  display: block;
  text-align: center;
  position: absolute;
  width: 100%;
  height: 100%;
  font-size: 1em;
  line-height: inherit;
  *line-height: 2em;
}
.icon-stack .icon-stack-base {
  font-size: 2em;
  *line-height: 1em;
}
/* Animated rotating icon */
.icon-spin {
  display: inline-block;
  -moz-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}
/* Prevent stack and spinners from being taken inline when inside a link */
a .icon-stack,
a .icon-spin {
  display: inline-block;
  text-decoration: none;
}
@-moz-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
  }
  100% {
    -moz-transform: rotate(359deg);
  }
}
@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
  }
}
@-o-keyframes spin {
  0% {
    -o-transform: rotate(0deg);
  }
  100% {
    -o-transform: rotate(359deg);
  }
}
@-ms-keyframes spin {
  0% {
    -ms-transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(359deg);
  }
}
@keyframes spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
/* Icon rotations and mirroring */
.icon-rotate-90:before {
  -webkit-transform: rotate(90deg);
  -moz-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  -o-transform: rotate(90deg);
  transform: rotate(90deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
}
.icon-rotate-180:before {
  -webkit-transform: rotate(180deg);
  -moz-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  -o-transform: rotate(180deg);
  transform: rotate(180deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
}
.icon-rotate-270:before {
  -webkit-transform: rotate(270deg);
  -moz-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  -o-transform: rotate(270deg);
  transform: rotate(270deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
}
.icon-flip-horizontal:before {
  -webkit-transform: scale(-1, 1);
  -moz-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  -o-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.icon-flip-vertical:before {
  -webkit-transform: scale(1, -1);
  -moz-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  -o-transform: scale(1, -1);
  transform: scale(1, -1);
}
/* ensure rotation occurs inside anchor tags */
a .icon-rotate-90:before,
a .icon-rotate-180:before,
a .icon-rotate-270:before,
a .icon-flip-horizontal:before,
a .icon-flip-vertical:before {
  display: inline-block;
}
/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.icon-glass:before {
  content: "\f000";
}
.icon-music:before {
  content: "\f001";
}
.icon-search:before {
  content: "\f002";
}
.icon-envelope-alt:before {
  content: "\f003";
}
.icon-heart:before {
  content: "\f004";
}
.icon-star:before {
  content: "\f005";
}
.icon-star-empty:before {
  content: "\f006";
}
.icon-user:before {
  content: "\f007";
}
.icon-film:before {
  content: "\f008";
}
.icon-th-large:before {
  content: "\f009";
}
.icon-th:before {
  content: "\f00a";
}
.icon-th-list:before {
  content: "\f00b";
}
.icon-ok:before {
  content: "\f00c";
}
.icon-remove:before {
  content: "\f00d";
}
.icon-zoom-in:before {
  content: "\f00e";
}
.icon-zoom-out:before {
  content: "\f010";
}
.icon-power-off:before,
.icon-off:before {
  content: "\f011";
}
.icon-signal:before {
  content: "\f012";
}
.icon-gear:before,
.icon-cog:before {
  content: "\f013";
}
.icon-trash:before {
  content: "\f014";
}
.icon-home:before {
  content: "\f015";
}
.icon-file-alt:before {
  content: "\f016";
}
.icon-time:before {
  content: "\f017";
}
.icon-road:before {
  content: "\f018";
}
.icon-download-alt:before {
  content: "\f019";
}
.icon-download:before {
  content: "\f01a";
}
.icon-upload:before {
  content: "\f01b";
}
.icon-inbox:before {
  content: "\f01c";
}
.icon-play-circle:before {
  content: "\f01d";
}
.icon-rotate-right:before,
.icon-repeat:before {
  content: "\f01e";
}
.icon-refresh:before {
  content: "\f021";
}
.icon-list-alt:before {
  content: "\f022";
}
.icon-lock:before {
  content: "\f023";
}
.icon-flag:before {
  content: "\f024";
}
.icon-headphones:before {
  content: "\f025";
}
.icon-volume-off:before {
  content: "\f026";
}
.icon-volume-down:before {
  content: "\f027";
}
.icon-volume-up:before {
  content: "\f028";
}
.icon-qrcode:before {
  content: "\f029";
}
.icon-barcode:before {
  content: "\f02a";
}
.icon-tag:before {
  content: "\f02b";
}
.icon-tags:before {
  content: "\f02c";
}
.icon-book:before {
  content: "\f02d";
}
.icon-bookmark:before {
  content: "\f02e";
}
.icon-print:before {
  content: "\f02f";
}
.icon-camera:before {
  content: "\f030";
}
.icon-font:before {
  content: "\f031";
}
.icon-bold:before {
  content: "\f032";
}
.icon-italic:before {
  content: "\f033";
}
.icon-text-height:before {
  content: "\f034";
}
.icon-text-width:before {
  content: "\f035";
}
.icon-align-left:before {
  content: "\f036";
}
.icon-align-center:before {
  content: "\f037";
}
.icon-align-right:before {
  content: "\f038";
}
.icon-align-justify:before {
  content: "\f039";
}
.icon-list:before {
  content: "\f03a";
}
.icon-indent-left:before {
  content: "\f03b";
}
.icon-indent-right:before {
  content: "\f03c";
}
.icon-facetime-video:before {
  content: "\f03d";
}
.icon-picture:before {
  content: "\f03e";
}
.icon-pencil:before {
  content: "\f040";
}
.icon-map-marker:before {
  content: "\f041";
}
.icon-adjust:before {
  content: "\f042";
}
.icon-tint:before {
  content: "\f043";
}
.icon-edit:before {
  content: "\f044";
}
.icon-share:before {
  content: "\f045";
}
.icon-check:before {
  content: "\f046";
}
.icon-move:before {
  content: "\f047";
}
.icon-step-backward:before {
  content: "\f048";
}
.icon-fast-backward:before {
  content: "\f049";
}
.icon-backward:before {
  content: "\f04a";
}
.icon-play:before {
  content: "\f04b";
}
.icon-pause:before {
  content: "\f04c";
}
.icon-stop:before {
  content: "\f04d";
}
.icon-forward:before {
  content: "\f04e";
}
.icon-fast-forward:before {
  content: "\f050";
}
.icon-step-forward:before {
  content: "\f051";
}
.icon-eject:before {
  content: "\f052";
}
.icon-chevron-left:before {
  content: "\f053";
}
.icon-chevron-right:before {
  content: "\f054";
}
.icon-plus-sign:before {
  content: "\f055";
}
.icon-minus-sign:before {
  content: "\f056";
}
.icon-remove-sign:before {
  content: "\f057";
}
.icon-ok-sign:before {
  content: "\f058";
}
.icon-question-sign:before {
  content: "\f059";
}
.icon-info-sign:before {
  content: "\f05a";
}
.icon-screenshot:before {
  content: "\f05b";
}
.icon-remove-circle:before {
  content: "\f05c";
}
.icon-ok-circle:before {
  content: "\f05d";
}
.icon-ban-circle:before {
  content: "\f05e";
}
.icon-arrow-left:before {
  content: "\f060";
}
.icon-arrow-right:before {
  content: "\f061";
}
.icon-arrow-up:before {
  content: "\f062";
}
.icon-arrow-down:before {
  content: "\f063";
}
.icon-mail-forward:before,
.icon-share-alt:before {
  content: "\f064";
}
.icon-resize-full:before {
  content: "\f065";
}
.icon-resize-small:before {
  content: "\f066";
}
.icon-plus:before {
  content: "\f067";
}
.icon-minus:before {
  content: "\f068";
}
.icon-asterisk:before {
  content: "\f069";
}
.icon-exclamation-sign:before {
  content: "\f06a";
}
.icon-gift:before {
  content: "\f06b";
}
.icon-leaf:before {
  content: "\f06c";
}
.icon-fire:before {
  content: "\f06d";
}
.icon-eye-open:before {
  content: "\f06e";
}
.icon-eye-close:before {
  content: "\f070";
}
.icon-warning-sign:before {
  content: "\f071";
}
.icon-plane:before {
  content: "\f072";
}
.icon-calendar:before {
  content: "\f073";
}
.icon-random:before {
  content: "\f074";
}
.icon-comment:before {
  content: "\f075";
}
.icon-magnet:before {
  content: "\f076";
}
.icon-chevron-up:before {
  content: "\f077";
}
.icon-chevron-down:before {
  content: "\f078";
}
.icon-retweet:before {
  content: "\f079";
}
.icon-shopping-cart:before {
  content: "\f07a";
}
.icon-folder-close:before {
  content: "\f07b";
}
.icon-folder-open:before {
  content: "\f07c";
}
.icon-resize-vertical:before {
  content: "\f07d";
}
.icon-resize-horizontal:before {
  content: "\f07e";
}
.icon-bar-chart:before {
  content: "\f080";
}
.icon-twitter-sign:before {
  content: "\f081";
}
.icon-facebook-sign:before {
  content: "\f082";
}
.icon-camera-retro:before {
  content: "\f083";
}
.icon-key:before {
  content: "\f084";
}
.icon-gears:before,
.icon-cogs:before {
  content: "\f085";
}
.icon-comments:before {
  content: "\f086";
}
.icon-thumbs-up-alt:before {
  content: "\f087";
}
.icon-thumbs-down-alt:before {
  content: "\f088";
}
.icon-star-half:before {
  content: "\f089";
}
.icon-heart-empty:before {
  content: "\f08a";
}
.icon-signout:before {
  content: "\f08b";
}
.icon-linkedin-sign:before {
  content: "\f08c";
}
.icon-pushpin:before {
  content: "\f08d";
}
.icon-external-link:before {
  content: "\f08e";
}
.icon-signin:before {
  content: "\f090";
}
.icon-trophy:before {
  content: "\f091";
}
.icon-github-sign:before {
  content: "\f092";
}
.icon-upload-alt:before {
  content: "\f093";
}
.icon-lemon:before {
  content: "\f094";
}
.icon-phone:before {
  content: "\f095";
}
.icon-unchecked:before,
.icon-check-empty:before {
  content: "\f096";
}
.icon-bookmark-empty:before {
  content: "\f097";
}
.icon-phone-sign:before {
  content: "\f098";
}
.icon-twitter:before {
  content: "\f099";
}
.icon-facebook:before {
  content: "\f09a";
}
.icon-github:before {
  content: "\f09b";
}
.icon-unlock:before {
  content: "\f09c";
}
.icon-credit-card:before {
  content: "\f09d";
}
.icon-rss:before {
  content: "\f09e";
}
.icon-hdd:before {
  content: "\f0a0";
}
.icon-bullhorn:before {
  content: "\f0a1";
}
.icon-bell:before {
  content: "\f0a2";
}
.icon-certificate:before {
  content: "\f0a3";
}
.icon-hand-right:before {
  content: "\f0a4";
}
.icon-hand-left:before {
  content: "\f0a5";
}
.icon-hand-up:before {
  content: "\f0a6";
}
.icon-hand-down:before {
  content: "\f0a7";
}
.icon-circle-arrow-left:before {
  content: "\f0a8";
}
.icon-circle-arrow-right:before {
  content: "\f0a9";
}
.icon-circle-arrow-up:before {
  content: "\f0aa";
}
.icon-circle-arrow-down:before {
  content: "\f0ab";
}
.icon-globe:before {
  content: "\f0ac";
}
.icon-wrench:before {
  content: "\f0ad";
}
.icon-tasks:before {
  content: "\f0ae";
}
.icon-filter:before {
  content: "\f0b0";
}
.icon-briefcase:before {
  content: "\f0b1";
}
.icon-fullscreen:before {
  content: "\f0b2";
}
.icon-group:before {
  content: "\f0c0";
}
.icon-link:before {
  content: "\f0c1";
}
.icon-cloud:before {
  content: "\f0c2";
}
.icon-beaker:before {
  content: "\f0c3";
}
.icon-cut:before {
  content: "\f0c4";
}
.icon-copy:before {
  content: "\f0c5";
}
.icon-paperclip:before,
.icon-paper-clip:before {
  content: "\f0c6";
}
.icon-save:before {
  content: "\f0c7";
}
.icon-sign-blank:before {
  content: "\f0c8";
}
.icon-reorder:before {
  content: "\f0c9";
}
.icon-list-ul:before {
  content: "\f0ca";
}
.icon-list-ol:before {
  content: "\f0cb";
}
.icon-strikethrough:before {
  content: "\f0cc";
}
.icon-underline:before {
  content: "\f0cd";
}
.icon-table:before {
  content: "\f0ce";
}
.icon-magic:before {
  content: "\f0d0";
}
.icon-truck:before {
  content: "\f0d1";
}
.icon-pinterest:before {
  content: "\f0d2";
}
.icon-pinterest-sign:before {
  content: "\f0d3";
}
.icon-google-plus-sign:before {
  content: "\f0d4";
}
.icon-google-plus:before {
  content: "\f0d5";
}
.icon-money:before {
  content: "\f0d6";
}
.icon-caret-down:before {
  content: "\f0d7";
}
.icon-caret-up:before {
  content: "\f0d8";
}
.icon-caret-left:before {
  content: "\f0d9";
}
.icon-caret-right:before {
  content: "\f0da";
}
.icon-columns:before {
  content: "\f0db";
}
.icon-sort:before {
  content: "\f0dc";
}
.icon-sort-down:before {
  content: "\f0dd";
}
.icon-sort-up:before {
  content: "\f0de";
}
.icon-envelope:before {
  content: "\f0e0";
}
.icon-linkedin:before {
  content: "\f0e1";
}
.icon-rotate-left:before,
.icon-undo:before {
  content: "\f0e2";
}
.icon-legal:before {
  content: "\f0e3";
}
.icon-dashboard:before {
  content: "\f0e4";
}
.icon-comment-alt:before {
  content: "\f0e5";
}
.icon-comments-alt:before {
  content: "\f0e6";
}
.icon-bolt:before {
  content: "\f0e7";
}
.icon-sitemap:before {
  content: "\f0e8";
}
.icon-umbrella:before {
  content: "\f0e9";
}
.icon-paste:before {
  content: "\f0ea";
}
.icon-lightbulb:before {
  content: "\f0eb";
}
.icon-exchange:before {
  content: "\f0ec";
}
.icon-cloud-download:before {
  content: "\f0ed";
}
.icon-cloud-upload:before {
  content: "\f0ee";
}
.icon-user-md:before {
  content: "\f0f0";
}
.icon-stethoscope:before {
  content: "\f0f1";
}
.icon-suitcase:before {
  content: "\f0f2";
}
.icon-bell-alt:before {
  content: "\f0f3";
}
.icon-coffee:before {
  content: "\f0f4";
}
.icon-food:before {
  content: "\f0f5";
}
.icon-file-text-alt:before {
  content: "\f0f6";
}
.icon-building:before {
  content: "\f0f7";
}
.icon-hospital:before {
  content: "\f0f8";
}
.icon-ambulance:before {
  content: "\f0f9";
}
.icon-medkit:before {
  content: "\f0fa";
}
.icon-fighter-jet:before {
  content: "\f0fb";
}
.icon-beer:before {
  content: "\f0fc";
}
.icon-h-sign:before {
  content: "\f0fd";
}
.icon-plus-sign-alt:before {
  content: "\f0fe";
}
.icon-double-angle-left:before {
  content: "\f100";
}
.icon-double-angle-right:before {
  content: "\f101";
}
.icon-double-angle-up:before {
  content: "\f102";
}
.icon-double-angle-down:before {
  content: "\f103";
}
.icon-angle-left:before {
  content: "\f104";
}
.icon-angle-right:before {
  content: "\f105";
}
.icon-angle-up:before {
  content: "\f106";
}
.icon-angle-down:before {
  content: "\f107";
}
.icon-desktop:before {
  content: "\f108";
}
.icon-laptop:before {
  content: "\f109";
}
.icon-tablet:before {
  content: "\f10a";
}
.icon-mobile-phone:before {
  content: "\f10b";
}
.icon-circle-blank:before {
  content: "\f10c";
}
.icon-quote-left:before {
  content: "\f10d";
}
.icon-quote-right:before {
  content: "\f10e";
}
.icon-spinner:before {
  content: "\f110";
}
.icon-circle:before {
  content: "\f111";
}
.icon-mail-reply:before,
.icon-reply:before {
  content: "\f112";
}
.icon-github-alt:before {
  content: "\f113";
}
.icon-folder-close-alt:before {
  content: "\f114";
}
.icon-folder-open-alt:before {
  content: "\f115";
}
.icon-expand-alt:before {
  content: "\f116";
}
.icon-collapse-alt:before {
  content: "\f117";
}
.icon-smile:before {
  content: "\f118";
}
.icon-frown:before {
  content: "\f119";
}
.icon-meh:before {
  content: "\f11a";
}
.icon-gamepad:before {
  content: "\f11b";
}
.icon-keyboard:before {
  content: "\f11c";
}
.icon-flag-alt:before {
  content: "\f11d";
}
.icon-flag-checkered:before {
  content: "\f11e";
}
.icon-terminal:before {
  content: "\f120";
}
.icon-code:before {
  content: "\f121";
}
.icon-reply-all:before {
  content: "\f122";
}
.icon-mail-reply-all:before {
  content: "\f122";
}
.icon-star-half-full:before,
.icon-star-half-empty:before {
  content: "\f123";
}
.icon-location-arrow:before {
  content: "\f124";
}
.icon-crop:before {
  content: "\f125";
}
.icon-code-fork:before {
  content: "\f126";
}
.icon-unlink:before {
  content: "\f127";
}
.icon-question:before {
  content: "\f128";
}
.icon-info:before {
  content: "\f129";
}
.icon-exclamation:before {
  content: "\f12a";
}
.icon-superscript:before {
  content: "\f12b";
}
.icon-subscript:before {
  content: "\f12c";
}
.icon-eraser:before {
  content: "\f12d";
}
.icon-puzzle-piece:before {
  content: "\f12e";
}
.icon-microphone:before {
  content: "\f130";
}
.icon-microphone-off:before {
  content: "\f131";
}
.icon-shield:before {
  content: "\f132";
}
.icon-calendar-empty:before {
  content: "\f133";
}
.icon-fire-extinguisher:before {
  content: "\f134";
}
.icon-rocket:before {
  content: "\f135";
}
.icon-maxcdn:before {
  content: "\f136";
}
.icon-chevron-sign-left:before {
  content: "\f137";
}
.icon-chevron-sign-right:before {
  content: "\f138";
}
.icon-chevron-sign-up:before {
  content: "\f139";
}
.icon-chevron-sign-down:before {
  content: "\f13a";
}
.icon-html5:before {
  content: "\f13b";
}
.icon-css3:before {
  content: "\f13c";
}
.icon-anchor:before {
  content: "\f13d";
}
.icon-unlock-alt:before {
  content: "\f13e";
}
.icon-bullseye:before {
  content: "\f140";
}
.icon-ellipsis-horizontal:before {
  content: "\f141";
}
.icon-ellipsis-vertical:before {
  content: "\f142";
}
.icon-rss-sign:before {
  content: "\f143";
}
.icon-play-sign:before {
  content: "\f144";
}
.icon-ticket:before {
  content: "\f145";
}
.icon-minus-sign-alt:before {
  content: "\f146";
}
.icon-check-minus:before {
  content: "\f147";
}
.icon-level-up:before {
  content: "\f148";
}
.icon-level-down:before {
  content: "\f149";
}
.icon-check-sign:before {
  content: "\f14a";
}
.icon-edit-sign:before {
  content: "\f14b";
}
.icon-external-link-sign:before {
  content: "\f14c";
}
.icon-share-sign:before {
  content: "\f14d";
}
.icon-compass:before {
  content: "\f14e";
}
.icon-collapse:before {
  content: "\f150";
}
.icon-collapse-top:before {
  content: "\f151";
}
.icon-expand:before {
  content: "\f152";
}
.icon-euro:before,
.icon-eur:before {
  content: "\f153";
}
.icon-gbp:before {
  content: "\f154";
}
.icon-dollar:before,
.icon-usd:before {
  content: "\f155";
}
.icon-rupee:before,
.icon-inr:before {
  content: "\f156";
}
.icon-yen:before,
.icon-jpy:before {
  content: "\f157";
}
.icon-renminbi:before,
.icon-cny:before {
  content: "\f158";
}
.icon-won:before,
.icon-krw:before {
  content: "\f159";
}
.icon-bitcoin:before,
.icon-btc:before {
  content: "\f15a";
}
.icon-file:before {
  content: "\f15b";
}
.icon-file-text:before {
  content: "\f15c";
}
.icon-sort-by-alphabet:before {
  content: "\f15d";
}
.icon-sort-by-alphabet-alt:before {
  content: "\f15e";
}
.icon-sort-by-attributes:before {
  content: "\f160";
}
.icon-sort-by-attributes-alt:before {
  content: "\f161";
}
.icon-sort-by-order:before {
  content: "\f162";
}
.icon-sort-by-order-alt:before {
  content: "\f163";
}
.icon-thumbs-up:before {
  content: "\f164";
}
.icon-thumbs-down:before {
  content: "\f165";
}
.icon-youtube-sign:before {
  content: "\f166";
}
.icon-youtube:before {
  content: "\f167";
}
.icon-xing:before {
  content: "\f168";
}
.icon-xing-sign:before {
  content: "\f169";
}
.icon-youtube-play:before {
  content: "\f16a";
}
.icon-dropbox:before {
  content: "\f16b";
}
.icon-stackexchange:before {
  content: "\f16c";
}
.icon-instagram:before {
  content: "\f16d";
}
.icon-flickr:before {
  content: "\f16e";
}
.icon-adn:before {
  content: "\f170";
}
.icon-bitbucket:before {
  content: "\f171";
}
.icon-bitbucket-sign:before {
  content: "\f172";
}
.icon-tumblr:before {
  content: "\f173";
}
.icon-tumblr-sign:before {
  content: "\f174";
}
.icon-long-arrow-down:before {
  content: "\f175";
}
.icon-long-arrow-up:before {
  content: "\f176";
}
.icon-long-arrow-left:before {
  content: "\f177";
}
.icon-long-arrow-right:before {
  content: "\f178";
}
.icon-apple:before {
  content: "\f179";
}
.icon-windows:before {
  content: "\f17a";
}
.icon-android:before {
  content: "\f17b";
}
.icon-linux:before {
  content: "\f17c";
}
.icon-dribbble:before {
  content: "\f17d";
}
.icon-skype:before {
  content: "\f17e";
}
.icon-foursquare:before {
  content: "\f180";
}
.icon-trello:before {
  content: "\f181";
}
.icon-female:before {
  content: "\f182";
}
.icon-male:before {
  content: "\f183";
}
.icon-gittip:before {
  content: "\f184";
}
.icon-sun:before {
  content: "\f185";
}
.icon-moon:before {
  content: "\f186";
}
.icon-archive:before {
  content: "\f187";
}
.icon-bug:before {
  content: "\f188";
}
.icon-vk:before {
  content: "\f189";
}
.icon-weibo:before {
  content: "\f18a";
}
.icon-renren:before {
  content: "\f18b";
}
/*!
 *  Font Awesome 3.2.1
 *  the iconic font designed for Bootstrap
 *  ------------------------------------------------------------------------------
 *  The full suite of pictographic icons, examples, and documentation can be
 *  found at http://fontawesome.io.  Stay up to date on Twitter at
 *  http://twitter.com/fontawesome.
 *
 *  License
 *  ------------------------------------------------------------------------------
 *  - The Font Awesome font is licensed under SIL OFL 1.1 -
 *    http://scripts.sil.org/OFL
 *  - Font Awesome CSS, LESS, and SASS files are licensed under MIT License -
 *    http://opensource.org/licenses/mit-license.html
 *  - Font Awesome documentation licensed under CC BY 3.0 -
 *    http://creativecommons.org/licenses/by/3.0/
 *  - Attribution is no longer required in Font Awesome 3.0, but much appreciated:
 *    "Font Awesome by Dave Gandy - http://fontawesome.io"
 *
 *  Author - Dave Gandy
 *  ------------------------------------------------------------------------------
 *  Email: dave@fontawesome.io
 *  Twitter: http://twitter.com/davegandy
 *  Work: Lead Product Designer @ Kyruus - http://kyruus.com
 */
.lt-ie8 .icon-large {
  font-size: 1.3333333333333333em;
  margin-top: -4px;
  padding-top: 3px;
  margin-bottom: -4px;
  padding-bottom: 3px;
  vertical-align: middle;
}
.lt-ie8 .nav [class^="icon-"],
.lt-ie8 .nav [class*=" icon-"] {
  vertical-align: middle;
  margin-top: -4px;
  padding-top: 3px;
  margin-bottom: -4px;
  padding-bottom: 3px;
}
.lt-ie8 .nav [class^="icon-"].icon-large,
.lt-ie8 .nav [class*=" icon-"].icon-large {
  vertical-align: -25%;
}
.lt-ie8 .nav-pills [class^="icon-"].icon-large,
.lt-ie8 .nav-tabs [class^="icon-"].icon-large,
.lt-ie8 .nav-pills [class*=" icon-"].icon-large,
.lt-ie8 .nav-tabs [class*=" icon-"].icon-large {
  line-height: .75em;
  margin-top: -7px;
  padding-top: 5px;
  margin-bottom: -5px;
  padding-bottom: 4px;
}
.lt-ie8 .btn [class^="icon-"].pull-left,
.lt-ie8 .btn [class*=" icon-"].pull-left,
.lt-ie8 .btn [class^="icon-"].pull-right,
.lt-ie8 .btn [class*=" icon-"].pull-right {
  vertical-align: inherit;
}
.lt-ie8 .btn [class^="icon-"].icon-large,
.lt-ie8 .btn [class*=" icon-"].icon-large {
  margin-top: -0.5em;
}
.lt-ie8 a [class^="icon-"],
.lt-ie8 a [class*=" icon-"] {
  cursor: pointer;
}
.icon-glass {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf000;');
}
.icon-music {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf001;');
}
.icon-search {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf002;');
}
.icon-envelope-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf003;');
}
.icon-heart {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf004;');
}
.icon-star {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf005;');
}
.icon-star-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf006;');
}
.icon-user {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf007;');
}
.icon-film {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf008;');
}
.icon-th-large {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf009;');
}
.icon-th {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf00a;');
}
.icon-th-list {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf00b;');
}
.icon-ok {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf00c;');
}
.icon-remove {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf00d;');
}
.icon-zoom-in {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf00e;');
}
.icon-zoom-out {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf010;');
}
.icon-off {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf011;');
}
.icon-power-off {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf011;');
}
.icon-signal {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf012;');
}
.icon-cog {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf013;');
}
.icon-gear {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf013;');
}
.icon-trash {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf014;');
}
.icon-home {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf015;');
}
.icon-file-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf016;');
}
.icon-time {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf017;');
}
.icon-road {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf018;');
}
.icon-download-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf019;');
}
.icon-download {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01a;');
}
.icon-upload {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01b;');
}
.icon-inbox {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01c;');
}
.icon-play-circle {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01d;');
}
.icon-repeat {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01e;');
}
.icon-rotate-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf01e;');
}
.icon-refresh {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf021;');
}
.icon-list-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf022;');
}
.icon-lock {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf023;');
}
.icon-flag {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf024;');
}
.icon-headphones {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf025;');
}
.icon-volume-off {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf026;');
}
.icon-volume-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf027;');
}
.icon-volume-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf028;');
}
.icon-qrcode {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf029;');
}
.icon-barcode {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02a;');
}
.icon-tag {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02b;');
}
.icon-tags {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02c;');
}
.icon-book {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02d;');
}
.icon-bookmark {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02e;');
}
.icon-print {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf02f;');
}
.icon-camera {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf030;');
}
.icon-font {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf031;');
}
.icon-bold {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf032;');
}
.icon-italic {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf033;');
}
.icon-text-height {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf034;');
}
.icon-text-width {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf035;');
}
.icon-align-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf036;');
}
.icon-align-center {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf037;');
}
.icon-align-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf038;');
}
.icon-align-justify {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf039;');
}
.icon-list {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf03a;');
}
.icon-indent-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf03b;');
}
.icon-indent-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf03c;');
}
.icon-facetime-video {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf03d;');
}
.icon-picture {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf03e;');
}
.icon-pencil {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf040;');
}
.icon-map-marker {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf041;');
}
.icon-adjust {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf042;');
}
.icon-tint {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf043;');
}
.icon-edit {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf044;');
}
.icon-share {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf045;');
}
.icon-check {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf046;');
}
.icon-move {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf047;');
}
.icon-step-backward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf048;');
}
.icon-fast-backward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf049;');
}
.icon-backward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf04a;');
}
.icon-play {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf04b;');
}
.icon-pause {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf04c;');
}
.icon-stop {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf04d;');
}
.icon-forward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf04e;');
}
.icon-fast-forward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf050;');
}
.icon-step-forward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf051;');
}
.icon-eject {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf052;');
}
.icon-chevron-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf053;');
}
.icon-chevron-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf054;');
}
.icon-plus-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf055;');
}
.icon-minus-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf056;');
}
.icon-remove-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf057;');
}
.icon-ok-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf058;');
}
.icon-question-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf059;');
}
.icon-info-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf05a;');
}
.icon-screenshot {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf05b;');
}
.icon-remove-circle {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf05c;');
}
.icon-ok-circle {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf05d;');
}
.icon-ban-circle {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf05e;');
}
.icon-arrow-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf060;');
}
.icon-arrow-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf061;');
}
.icon-arrow-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf062;');
}
.icon-arrow-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf063;');
}
.icon-share-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf064;');
}
.icon-mail-forward {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf064;');
}
.icon-resize-full {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf065;');
}
.icon-resize-small {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf066;');
}
.icon-plus {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf067;');
}
.icon-minus {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf068;');
}
.icon-asterisk {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf069;');
}
.icon-exclamation-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf06a;');
}
.icon-gift {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf06b;');
}
.icon-leaf {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf06c;');
}
.icon-fire {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf06d;');
}
.icon-eye-open {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf06e;');
}
.icon-eye-close {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf070;');
}
.icon-warning-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf071;');
}
.icon-plane {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf072;');
}
.icon-calendar {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf073;');
}
.icon-random {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf074;');
}
.icon-comment {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf075;');
}
.icon-magnet {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf076;');
}
.icon-chevron-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf077;');
}
.icon-chevron-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf078;');
}
.icon-retweet {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf079;');
}
.icon-shopping-cart {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf07a;');
}
.icon-folder-close {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf07b;');
}
.icon-folder-open {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf07c;');
}
.icon-resize-vertical {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf07d;');
}
.icon-resize-horizontal {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf07e;');
}
.icon-bar-chart {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf080;');
}
.icon-twitter-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf081;');
}
.icon-facebook-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf082;');
}
.icon-camera-retro {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf083;');
}
.icon-key {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf084;');
}
.icon-cogs {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf085;');
}
.icon-gears {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf085;');
}
.icon-comments {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf086;');
}
.icon-thumbs-up-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf087;');
}
.icon-thumbs-down-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf088;');
}
.icon-star-half {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf089;');
}
.icon-heart-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf08a;');
}
.icon-signout {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf08b;');
}
.icon-linkedin-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf08c;');
}
.icon-pushpin {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf08d;');
}
.icon-external-link {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf08e;');
}
.icon-signin {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf090;');
}
.icon-trophy {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf091;');
}
.icon-github-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf092;');
}
.icon-upload-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf093;');
}
.icon-lemon {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf094;');
}
.icon-phone {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf095;');
}
.icon-check-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf096;');
}
.icon-unchecked {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf096;');
}
.icon-bookmark-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf097;');
}
.icon-phone-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf098;');
}
.icon-twitter {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf099;');
}
.icon-facebook {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf09a;');
}
.icon-github {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf09b;');
}
.icon-unlock {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf09c;');
}
.icon-credit-card {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf09d;');
}
.icon-rss {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf09e;');
}
.icon-hdd {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a0;');
}
.icon-bullhorn {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a1;');
}
.icon-bell {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a2;');
}
.icon-certificate {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a3;');
}
.icon-hand-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a4;');
}
.icon-hand-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a5;');
}
.icon-hand-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a6;');
}
.icon-hand-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a7;');
}
.icon-circle-arrow-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a8;');
}
.icon-circle-arrow-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0a9;');
}
.icon-circle-arrow-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0aa;');
}
.icon-circle-arrow-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ab;');
}
.icon-globe {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ac;');
}
.icon-wrench {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ad;');
}
.icon-tasks {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ae;');
}
.icon-filter {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0b0;');
}
.icon-briefcase {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0b1;');
}
.icon-fullscreen {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0b2;');
}
.icon-group {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c0;');
}
.icon-link {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c1;');
}
.icon-cloud {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c2;');
}
.icon-beaker {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c3;');
}
.icon-cut {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c4;');
}
.icon-copy {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c5;');
}
.icon-paper-clip {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c6;');
}
.icon-paperclip {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c6;');
}
.icon-save {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c7;');
}
.icon-sign-blank {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c8;');
}
.icon-reorder {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0c9;');
}
.icon-list-ul {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ca;');
}
.icon-list-ol {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0cb;');
}
.icon-strikethrough {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0cc;');
}
.icon-underline {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0cd;');
}
.icon-table {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ce;');
}
.icon-magic {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d0;');
}
.icon-truck {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d1;');
}
.icon-pinterest {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d2;');
}
.icon-pinterest-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d3;');
}
.icon-google-plus-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d4;');
}
.icon-google-plus {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d5;');
}
.icon-money {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d6;');
}
.icon-caret-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d7;');
}
.icon-caret-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d8;');
}
.icon-caret-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0d9;');
}
.icon-caret-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0da;');
}
.icon-columns {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0db;');
}
.icon-sort {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0dc;');
}
.icon-sort-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0dd;');
}
.icon-sort-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0de;');
}
.icon-envelope {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e0;');
}
.icon-linkedin {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e1;');
}
.icon-undo {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e2;');
}
.icon-rotate-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e2;');
}
.icon-legal {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e3;');
}
.icon-dashboard {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e4;');
}
.icon-comment-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e5;');
}
.icon-comments-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e6;');
}
.icon-bolt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e7;');
}
.icon-sitemap {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e8;');
}
.icon-umbrella {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0e9;');
}
.icon-paste {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ea;');
}
.icon-lightbulb {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0eb;');
}
.icon-exchange {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ec;');
}
.icon-cloud-download {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ed;');
}
.icon-cloud-upload {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0ee;');
}
.icon-user-md {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f0;');
}
.icon-stethoscope {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f1;');
}
.icon-suitcase {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f2;');
}
.icon-bell-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f3;');
}
.icon-coffee {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f4;');
}
.icon-food {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f5;');
}
.icon-file-text-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f6;');
}
.icon-building {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f7;');
}
.icon-hospital {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f8;');
}
.icon-ambulance {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0f9;');
}
.icon-medkit {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0fa;');
}
.icon-fighter-jet {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0fb;');
}
.icon-beer {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0fc;');
}
.icon-h-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0fd;');
}
.icon-plus-sign-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf0fe;');
}
.icon-double-angle-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf100;');
}
.icon-double-angle-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf101;');
}
.icon-double-angle-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf102;');
}
.icon-double-angle-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf103;');
}
.icon-angle-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf104;');
}
.icon-angle-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf105;');
}
.icon-angle-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf106;');
}
.icon-angle-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf107;');
}
.icon-desktop {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf108;');
}
.icon-laptop {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf109;');
}
.icon-tablet {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf10a;');
}
.icon-mobile-phone {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf10b;');
}
.icon-circle-blank {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf10c;');
}
.icon-quote-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf10d;');
}
.icon-quote-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf10e;');
}
.icon-spinner {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf110;');
}
.icon-circle {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf111;');
}
.icon-reply {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf112;');
}
.icon-mail-reply {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf112;');
}
.icon-github-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf113;');
}
.icon-folder-close-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf114;');
}
.icon-folder-open-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf115;');
}
.icon-expand-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf116;');
}
.icon-collapse-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf117;');
}
.icon-smile {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf118;');
}
.icon-frown {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf119;');
}
.icon-meh {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf11a;');
}
.icon-gamepad {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf11b;');
}
.icon-keyboard {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf11c;');
}
.icon-flag-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf11d;');
}
.icon-flag-checkered {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf11e;');
}
.icon-terminal {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf120;');
}
.icon-code {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf121;');
}
.icon-reply-all {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf122;');
}
.icon-mail-reply-all {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf122;');
}
.icon-star-half-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf123;');
}
.icon-star-half-full {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf123;');
}
.icon-location-arrow {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf124;');
}
.icon-crop {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf125;');
}
.icon-code-fork {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf126;');
}
.icon-unlink {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf127;');
}
.icon-question {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf128;');
}
.icon-info {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf129;');
}
.icon-exclamation {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf12a;');
}
.icon-superscript {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf12b;');
}
.icon-subscript {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf12c;');
}
.icon-eraser {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf12d;');
}
.icon-puzzle-piece {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf12e;');
}
.icon-microphone {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf130;');
}
.icon-microphone-off {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf131;');
}
.icon-shield {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf132;');
}
.icon-calendar-empty {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf133;');
}
.icon-fire-extinguisher {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf134;');
}
.icon-rocket {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf135;');
}
.icon-maxcdn {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf136;');
}
.icon-chevron-sign-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf137;');
}
.icon-chevron-sign-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf138;');
}
.icon-chevron-sign-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf139;');
}
.icon-chevron-sign-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf13a;');
}
.icon-html5 {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf13b;');
}
.icon-css3 {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf13c;');
}
.icon-anchor {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf13d;');
}
.icon-unlock-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf13e;');
}
.icon-bullseye {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf140;');
}
.icon-ellipsis-horizontal {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf141;');
}
.icon-ellipsis-vertical {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf142;');
}
.icon-rss-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf143;');
}
.icon-play-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf144;');
}
.icon-ticket {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf145;');
}
.icon-minus-sign-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf146;');
}
.icon-check-minus {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf147;');
}
.icon-level-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf148;');
}
.icon-level-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf149;');
}
.icon-check-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf14a;');
}
.icon-edit-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf14b;');
}
.icon-external-link-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf14c;');
}
.icon-share-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf14d;');
}
.icon-compass {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf14e;');
}
.icon-collapse {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf150;');
}
.icon-collapse-top {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf151;');
}
.icon-expand {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf152;');
}
.icon-eur {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf153;');
}
.icon-euro {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf153;');
}
.icon-gbp {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf154;');
}
.icon-usd {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf155;');
}
.icon-dollar {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf155;');
}
.icon-inr {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf156;');
}
.icon-rupee {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf156;');
}
.icon-jpy {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf157;');
}
.icon-yen {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf157;');
}
.icon-cny {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf158;');
}
.icon-renminbi {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf158;');
}
.icon-krw {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf159;');
}
.icon-won {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf159;');
}
.icon-btc {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15a;');
}
.icon-bitcoin {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15a;');
}
.icon-file {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15b;');
}
.icon-file-text {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15c;');
}
.icon-sort-by-alphabet {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15d;');
}
.icon-sort-by-alphabet-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf15e;');
}
.icon-sort-by-attributes {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf160;');
}
.icon-sort-by-attributes-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf161;');
}
.icon-sort-by-order {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf162;');
}
.icon-sort-by-order-alt {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf163;');
}
.icon-thumbs-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf164;');
}
.icon-thumbs-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf165;');
}
.icon-youtube-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf166;');
}
.icon-youtube {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf167;');
}
.icon-xing {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf168;');
}
.icon-xing-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf169;');
}
.icon-youtube-play {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf16a;');
}
.icon-dropbox {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf16b;');
}
.icon-stackexchange {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf16c;');
}
.icon-instagram {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf16d;');
}
.icon-flickr {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf16e;');
}
.icon-adn {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf170;');
}
.icon-bitbucket {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf171;');
}
.icon-bitbucket-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf172;');
}
.icon-tumblr {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf173;');
}
.icon-tumblr-sign {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf174;');
}
.icon-long-arrow-down {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf175;');
}
.icon-long-arrow-up {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf176;');
}
.icon-long-arrow-left {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf177;');
}
.icon-long-arrow-right {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf178;');
}
.icon-apple {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf179;');
}
.icon-windows {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf17a;');
}
.icon-android {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf17b;');
}
.icon-linux {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf17c;');
}
.icon-dribbble {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf17d;');
}
.icon-skype {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf17e;');
}
.icon-foursquare {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf180;');
}
.icon-trello {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf181;');
}
.icon-female {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf182;');
}
.icon-male {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf183;');
}
.icon-gittip {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf184;');
}
.icon-sun {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf185;');
}
.icon-moon {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf186;');
}
.icon-archive {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf187;');
}
.icon-bug {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf188;');
}
.icon-vk {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf189;');
}
.icon-weibo {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf18a;');
}
.icon-renren {
  *zoom: expression( this.runtimeStyle['zoom'] = '1', this.innerHTML = '&#xf18b;');
}
h1,
h2,
h3,
h4,
h5,
h6 {
  margin-bottom: 9px;
  margin-top: 0;
  font-weight: normal;
}
h1 {
  font-size: 30px;
}
h2 {
  font-size: 18px;
}
body {
  font-family: "Open Sans", 'Helvetica Neue', Helvetica, Arial, sans-serif;
  font-size: 12px;
}
label,
input,
button,
select,
textarea {
  font-size: 12px;
}
h3 {
  font-size: 20px;
}
h3.app-ico:before {
  display: none;
}
.btn {
  font-weight: normal;
}
.btn-group > .btn,
.btn-group > .dropdown-menu,
.btn {
  font-size: 12px;
}
.btn-warning,
.btn-success,
.btn-info {
  background-color: #f5f5f5;
  background-image: -moz-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -ms-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#e6e6e6));
  background-image: -webkit-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -o-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: linear-gradient(top, #ffffff, #e6e6e6);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
  color: inherit;
  *color: #333;
}
.btn-warning:hover,
.btn-success:hover,
.btn-info:hover,
.btn-warning:active,
.btn-success:active,
.btn-info:active,
.btn-warning.active,
.btn-success.active,
.btn-info.active,
.btn-warning.disabled,
.btn-success.disabled,
.btn-info.disabled,
.btn-warning[disabled],
.btn-success[disabled],
.btn-info[disabled] {
  background-color: #e6e6e6;
}
.btn-warning:active,
.btn-success:active,
.btn-info:active,
.btn-warning.active,
.btn-success.active,
.btn-info.active {
  background-color: #cccccc \9;
}
.btn-warning:hover,
.btn-success:hover,
.btn-info:hover,
.btn-warning:active,
.btn-success:active,
.btn-info:active {
  color: inherit;
  *color: #333;
}
.btn-primary {
  background-color: #006fb5;
  background-image: -moz-linear-gradient(top, #0083c9, #005096);
  background-image: -ms-linear-gradient(top, #0083c9, #005096);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0083c9), to(#005096));
  background-image: -webkit-linear-gradient(top, #0083c9, #005096);
  background-image: -o-linear-gradient(top, #0083c9, #005096);
  background-image: linear-gradient(top, #0083c9, #005096);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0083c9', endColorstr='#005096', GradientType=0);
  border-color: #005096 #005096 #00274a;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
}
.btn-primary:hover,
.btn-primary:active,
.btn-primary.active,
.btn-primary.disabled,
.btn-primary[disabled] {
  background-color: #005096;
}
.btn-primary:active,
.btn-primary.active {
  background-color: #003563 \9;
}
.btn-primary,
.btn-danger {
  font-weight: bold;
}
td .btn-toolbar {
  margin: 0;
}
.form-horizontal .control-label,
.form-stacked .control-label {
  text-align: left;
}
.form-horizontal .control-group,
.form-stacked .control-group {
  margin-bottom: 9px;
}
.form-horizontal input[type=text],
.form-stacked input[type=text],
.form-horizontal input[type=number],
.form-stacked input[type=number],
.form-horizontal input[type=email],
.form-stacked input[type=email],
.form-horizontal input[type=url],
.form-stacked input[type=url],
.form-horizontal textarea,
.form-stacked textarea,
.form-horizontal select,
.form-stacked select {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 12px;
  min-height: 35px;
}
.form-horizontal textarea,
.form-stacked textarea {
  max-height: 200px;
}
.form-inline select {
  min-width: 200px;
}
.form-inline {
  margin-bottom: 0;
}
.form-inline .help-block:first-child,
.form-inline .error-block:first-child {
  display: none;
}
.form-inline label {
  margin-right: 5px;
}
.form-inline .control-group {
  margin-right: 10px;
}
.fields-full input[type=text],
.fields-full textarea {
  width: 100%;
}
.well .form-actions,
.tabbable.dashboard .tab-content .form-actions {
  margin-bottom: 0;
  position: relative;
  bottom: -19px;
  left: -19px;
  width: 100%;
  padding: 19px;
  border-top-color: #ccc;
}
.tabbable.dashboard .tab-content .form-actions {
  bottom: -29px;
  left: -29px;
  padding-left: 29px;
  padding-right: 29px;
}
.well form .form-actions {
  bottom: -39px;
}
.create-page .form-horizontal input[type=text],
.create-page .form-stacked input[type=text],
.create-page .form-horizontal input[type=number],
.create-page .form-stacked input[type=number],
.create-page .form-horizontal input[type=email],
.create-page .form-stacked input[type=email],
.create-page .form-horizontal input[type=url],
.create-page .form-stacked input[type=url],
.create-page .form-horizontal textarea,
.create-page .form-stacked textarea {
  width: 95%;
}
.create-page .form-stacked .form-inline input[type=text],
.create-page .form-stacked .form-inline input[type=number],
.create-page .form-stacked .form-inline input[type=email],
.create-page .form-stacked .form-inline input[type=url],
.create-page .form-stacked .form-inline textarea {
  width: auto;
}
.create-page label {
  font-weight: bold;
}
input[type=text].hasDatepicker,
.create-page input[type=text].hasDatepicker,
.form-inline input[type=text].hasDatepicker,
.form-horizontal input[type=text].hasDatepicker,
.form-stacked input[type=text].hasDatepicker {
  width: 125px;
}
.wysihtml5-sandbox {
  border: 1px solid #ccc!important;
}
/* ADDITIONAL ERRORS */
.errorlist {
  margin: 0 0 0 20px;
  padding: 0 0 10px 0;
  color: #B94A48;
}
.errorlist li {
  padding: 0 0 5px 0;
  list-style: none;
}
.form-inline .help-block,
.form-inline .error-block {
  display: inline-block;
  margin: 0 20px 0 10px;
}
.form-inline .help-block li,
.form-inline .error-block li {
  list-style: none;
  color: #B94A48;
}
.form-inline input[type=number],
.form-inline input[type=email],
.form-inline input[type=url],
.form-inline input[type=text] {
  width: 140px;
}
.table-bordered,
.table-bordered th,
.table-bordered td {
  border-color: #bbb;
}
.table {
  background-color: #ffffff;
}
.table-striped tbody tr:nth-child(odd) td,
.table-striped tbody tr:nth-child(odd) th {
  background-color: #efefef;
}
.table-hover tbody tr:hover td,
.table-hover tbody tr:hover th {
  background-color: #FFF49F;
}
body {
  background: url("../img/ui/dashboard/bg_subtle_dots.png") repeat scroll 0 0 #ffffff;
}
.container-fluid.dashboard {
  margin: 0 auto;
  /*  max-width: 1170px;*/

  position: relative;
  padding: 0 20px;
}
.dashboard > .content {
  margin-top: 18px;
}
.navbar-accounts .navbar-inner {
  padding-left: 20px;
  padding-right: 20px;
  min-height: 50px;
  font-size: 12px;
  background-color: #2f2f2f;
  background-image: -moz-linear-gradient(top, #373737, #242424);
  background-image: -ms-linear-gradient(top, #373737, #242424);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#373737), to(#242424));
  background-image: -webkit-linear-gradient(top, #373737, #242424);
  background-image: -o-linear-gradient(top, #373737, #242424);
  background-image: linear-gradient(top, #373737, #242424);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#373737', endColorstr='#242424', GradientType=0);
  border: none;
}
.navbar-accounts .navbar-inner .brand {
  background: url("../img/ui/dashboard/logo_oscar.png") no-repeat scroll 0 0 transparent;
  text-indent: -9999px;
  display: block;
  width: 60px;
  height: 38px;
  padding: 0;
  margin-left: 0;
  margin-top: 5px;
}
.navbar-accounts .navbar-inner .nav {
  top: 5px;
}
.navbar-accounts .navbar-inner .nav > li > a {
  color: #C1C1C1;
}
.navbar .nav > li span {
  display: block;
  padding: 10px;
}
.navbar-inverse {
  color: #DCDCDC;
}
.subnav-fixed {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
  top: 50px;
  -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1);
  border-bottom: 1px solid #D5D5D5;
}
.navbar-primary .navbar-inner {
  background-color: #363636;
  background-image: -moz-linear-gradient(top, #353535, #373737);
  background-image: -ms-linear-gradient(top, #353535, #373737);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#353535), to(#373737));
  background-image: -webkit-linear-gradient(top, #353535, #373737);
  background-image: -o-linear-gradient(top, #353535, #373737);
  background-image: linear-gradient(top, #353535, #373737);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#353535', endColorstr='#373737', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false) !important;
  border-top: 1px solid #5B5B5B;
  *position: relative;
  *z-index: 10;
}
.navbar-primary .nav.nav-pills .open .dropdown-toggle {
  border-color: #444;
  border-right-color: #222;
}
.navbar-primary .nav > li > a {
  margin: 0;
  border-left: 1px solid #444;
  border-right: 1px solid #222222;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  color: #DCDCDC;
  font-size: 12px;
  padding: 15px;
}
.navbar-primary .nav > li > a .caret {
  border-top-color: #DCDCDC;
  border-bottom-color: #DCDCDC;
  margin-top: 4px;
}
.navbar-primary .nav > li .dropdown-menu {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.navbar-primary .nav > .active > a,
.navbar-primary .nav > .active > a:hover,
.navbar-primary .nav > li > a:hover,
.navbar-primary .nav-pills .open .dropdown-toggle {
  color: #B2DEF2;
  background-color: #373737;
  border-right-color: #222222;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.05);
  background-color: #292929;
  background-image: -moz-linear-gradient(top, #1f1f1f, #373737);
  background-image: -ms-linear-gradient(top, #1f1f1f, #373737);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#1f1f1f), to(#373737));
  background-image: -webkit-linear-gradient(top, #1f1f1f, #373737);
  background-image: -o-linear-gradient(top, #1f1f1f, #373737);
  background-image: linear-gradient(top, #1f1f1f, #373737);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#1f1f1f', endColorstr='#373737', GradientType=0);
}
.navbar-primary .nav > .active > a:before,
.navbar-primary .nav > .active > a:hover:before,
.navbar-primary .nav > li > a:hover:before,
.navbar-primary .nav-pills .open .dropdown-toggle:before {
  color: #B2DEF2;
}
.navbar-primary .nav > li i {
  color: #dcdcdc;
  padding-right: 12px;
}
.navbar-primary .nav > li > a:hover .caret {
  border-top-color: #B2DEF2;
  border-bottom-color: #B2DEF2;
}
.breadcrumb {
  margin-top: 20px;
}
button {
  background-color: transparent;
}
.page-header {
  padding: 0 0 10px 0;
  margin-bottom: 0;
  border-bottom: 0;
}
caption,
.table-header {
  *zoom: 1;
  font-weight: bold;
  font-size: 14px;
  margin-bottom: 0;
  border: 1px solid #ccc;
  border-bottom: none;
  background-color: #f0f0f0;
  background-image: -moz-linear-gradient(top, #f8f8f8, #e5e5e5);
  background-image: -ms-linear-gradient(top, #f8f8f8, #e5e5e5);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f8f8f8), to(#e5e5e5));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #e5e5e5);
  background-image: -o-linear-gradient(top, #f8f8f8, #e5e5e5);
  background-image: linear-gradient(top, #f8f8f8, #e5e5e5);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f8f8f8', endColorstr='#e5e5e5', GradientType=0);
  color: #242424;
  padding: 6px 10px;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
  text-align: left;
}
caption:before,
.table-header:before,
caption:after,
.table-header:after {
  display: table;
  content: "";
}
caption:after,
.table-header:after {
  clear: both;
}
caption .icon-large:before,
.table-header .icon-large:before {
  font-size: 18px;
}
caption h2,
.table-header h2,
caption h3,
.table-header h3 {
  font-weight: bold;
  font-size: 14px;
  line-height: normal;
  margin: 0;
}
caption h2 > i,
.table-header h2 > i,
caption h3 > i,
.table-header h3 > i {
  padding-right: 10px;
}
caption .btn-toolbar,
.table-header .btn-toolbar {
  margin-top: 0;
  margin-bottom: 0;
}
caption > i,
.table-header > i {
  padding-right: 10px;
}
.content-block {
  border: 1px solid #ccc;
  margin-bottom: 20px;
  padding: 15px;
  background: #ffffff;
}
.content-block .order-graph-details label {
  background-color: #F8F8F8;
  border: 1px solid #ccc;
  *zoom: 1;
  display: block;
  margin-bottom: 15px;
  padding: 12px;
  color: #878787;
  font-size: 12px;
}
.content-block .order-graph-details label:before,
.content-block .order-graph-details label:after {
  display: table;
  content: "";
}
.content-block .order-graph-details label:after {
  clear: both;
}
.content-block .order-graph-details label span {
  display: inline-block;
  font-weight: bold;
  width: 30%;
  font-size: 16px;
  color: #242424;
}
.content-block .order-graph-details label i {
  color: #0D84AE;
  margin-right: 5px;
  font-size: 18px;
}
.search-adv {
  margin: 0;
  position: relative;
}
.search-adv ul,
.search-adv li,
.search-adv li > label,
.search-adv > label,
.search-adv input[type=text] {
  display: inline-block;
}
.search-adv > input[type=text] {
  width: 80px;
}
.search-adv ul {
  margin: 0;
}
.no-float {
  float: none;
}
.control-group.pull-left.no-float > label {
  width: 140px;
}
.control-group.pull-left.no-float .controls {
  margin-left: 160px;
}
.pull-left.btn {
  margin-left: 20px;
}
.pull-left.no-float.btn {
  margin-left: 160px;
}
.controls ul {
  margin-left: 0px;
  list-style: none;
}
.alert-message.block-message.file_upload p {
  margin-right: 10px;
}
.tabs.product_managment {
  margin-bottom: 0px;
}
.tabs.product_managment li.active a {
  background-color: #efefef;
}
.tabbable.dashboard {
  margin-bottom: 18px;
}
.tabbable.dashboard .navbar,
.tabbable.dashboard .nav-tabs {
  margin-bottom: 0;
}
.tabbable.dashboard .tab-content {
  display: block;
  width: auto;
  border: 1px #E1E1E1 solid;
  border-top-width: 0;
  padding: 30px;
}
.well,
.alert,
.table-bordered {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.well {
  *zoom: 1;
  box-shadow: none;
  background-color: #efefef;
  border-color: #bbb;
}
.well:before,
.well:after {
  display: table;
  content: "";
}
.well:after {
  clear: both;
}
.well-success {
  background-color: #d3dfaa;
  border-color: #b8c689;
}
.well-danger {
  background-color: #fff49f;
  border-color: #ffe090;
}
.well-info {
  background-color: #e5eff1;
  border-color: #cce3e5;
}
.well-blank {
  background-color: #ffffff;
  border-color: rgba(0, 0, 0, 0.1);
}
.create-page .well,
.promotions .well-info {
  background-color: #ffffff;
}
.alert {
  background-color: #fff49f;
  border-color: #ede181;
  color: #333;
}
#order_graph {
  position: relative;
  margin-bottom: 5em;
  width: 99%;
  height: 330px;
}
.bar-caption {
  position: relative;
  text-align: center;
  top: 0;
}
.bar-caption h1 {
  font-size: 18px;
  color: #242424;
  font-weight: bold;
  text-transform: uppercase;
}
.bar-y-axis {
  position: absolute;
  top: 16px;
  width: 5em;
  margin: 0;
  padding: 0;
  float: left;
  display: inline;
}
.bar-y-axis li {
  list-style: none;
  height: 33px;
  float: right;
  color: #868686;
}
.bar-chart,
.bar-chart dt,
.bar-chart dd {
  margin: 0;
  padding: 0;
}
.bar-chart {
  position: absolute;
  top: 0;
  left: 0;
  width: 98%;
  height: 300px;
}
.bar-chart dd {
  position: relative;
  float: left;
  width: 8%;
  height: 330px;
  margin-top: 22px;
}
.bar-chart dd em {
  position: absolute;
  bottom: -2em;
  right: 0;
  font-style: inherit;
  color: #868686;
}
.bar-chart span {
  position: absolute;
  display: block;
  width: 30%;
  bottom: 0;
  right: 0;
  z-index: 1;
  color: #555555;
  text-align: center;
  text-decoration: none;
}
.bar-chart span p {
  position: relative;
  top: 1em;
  display: none;
  padding: 3px;
  color: #333333;
  z-index: 2;
  background-color: #ffffff;
  font-weight: bold;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.bar-chart span {
  height: 50%;
  background-color: #0d86b1;
  background-image: -moz-linear-gradient(top, #0e91bf, #0b759b);
  background-image: -ms-linear-gradient(top, #0e91bf, #0b759b);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0e91bf), to(#0b759b));
  background-image: -webkit-linear-gradient(top, #0e91bf, #0b759b);
  background-image: -o-linear-gradient(top, #0e91bf, #0b759b);
  background-image: linear-gradient(top, #0e91bf, #0b759b);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0e91bf', endColorstr='#0b759b', GradientType=0);
}
.order-summary {
  padding: 0px;
  margin: 0px;
  *zoom: 1;
  background: #efefef;
}
.order-summary:before,
.order-summary:after {
  display: table;
  content: "";
}
.order-summary:after {
  clear: both;
}
.order-summary > li {
  list-style: none;
}
.order-summary li {
  float: left;
}
.order-summary li li {
  float: none;
}
.order-summary li {
  width: 20%;
  text-align: center;
}
.order-summary div {
  border-left: 1px solid #dcdcdc;
  padding: 20px 10px;
  min-height: 85px;
}
.order-summary strong {
  display: block;
  margin-top: 20px;
}
.order-summary li {
  width: 16%;
}
.order-summary li:first-child div {
  border-left: none;
}
.orders_search {
  position: absolute;
  top: 40px;
  width: 100%;
  left: -20px;
  padding: 0 20px;
  background: #cfe1e3;
  *zoom: 1;
}
.orders_search:before,
.orders_search:after {
  display: table;
  content: "";
}
.orders_search:after {
  clear: both;
}
.orders_search .control-group:first-child {
  margin-top: 20px;
}
.orders_search .btn {
  margin-bottom: 20px;
}
.orders_search.collapse {
  display: none;
}
.orders_search.in.collapse {
  display: block;
}
.category-select {
  display: block;
  margin: 0;
}
.category-select a {
  color: #222222;
  text-decoration: none;
  padding: 3px 10px;
  display: block;
}
.category-select a:hover {
  background: #e1e1e1;
}
.category-select a.app-ico {
  color: #0088cc;
}
.category-select ul {
  margin: 0;
}
.category-select ul a {
  padding-left: 18px;
}
.category-select ul ul a {
  padding-left: 33px;
}
.category-select ul ul a ul a {
  padding-left: 48px;
}
.category-select li {
  display: block;
}
.category-select > li ul {
  -webkit-transition: all .2s linear;
  -moz-transition: all .2s linear;
  -o-transition: all .2s linear;
  -ms-transition: all .2s linear;
  transition: all .2s linear;
  overflow: hidden;
}
.ico_expand + ul {
  height: 0px;
}
.category-selected {
  margin: 0;
}
.category-selected li {
  display: block;
  width: 150px;
  *zoom: 1;
  margin-bottom: 9px;
}
.category-selected li:before,
.category-selected li:after {
  display: table;
  content: "";
}
.category-selected li:after {
  clear: both;
}
.category-selected span {
  float: right;
  display: block;
  background: #999999;
  color: white;
  padding: 1px 0 3px;
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
  font-size: 12px;
  line-height: 11px;
  width: 15px;
  font-weight: bold;
  text-align: center;
}
#product_category select {
  width: 350px;
}
.catalogue .tab-content {
  overflow: visible;
}
.upload-image {
  *zoom: 1;
  margin: 0;
  z-index: 1;
  position: relative;
}
.upload-image:before,
.upload-image:after {
  display: table;
  content: "";
}
.upload-image:after {
  clear: both;
}
.upload-image li {
  display: block;
  width: 200px;
  margin: 0 1% 2%;
  float: left;
  text-align: center;
}
.upload-image li > div {
  padding: 4px;
  background: #ccc;
  margin-bottom: 10px;
}
.upload-image li > div + label,
.upload-image li > div + label + input {
  display: none;
}
.upload-image div {
  background: #fff;
  position: relative;
  width: 200px;
  height: 200px;
  z-index: 200;
}
.upload-image img {
  position: absolute;
  margin: auto;
  top: 0;
  max-height: 200px;
  max-width: 200px;
  width: auto;
  height: auto;
  left: 0;
}
.upload-image .image-input {
  z-index: 800;
}
.upload-image .image-input button {
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.upload-image .input-field {
  position: relative;
  z-index: 1000;
  opacity: 0;
}
.upload-image .input-field input {
  border-width: 0;
  direction: ltr;
  cursor: pointer;
  width: 200px;
  height: 200px;
}
div[data-spy="affix"] {
  width: 266px;
}
div[data-spy="affix"].affix {
  top: 18px;
}
.bs-docs-sidenav {
  padding: 0;
  background-color: #fff;
  -webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  -moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
}
.bs-docs-sidenav > li > a,
.bs-docs-sidenav > li > span {
  display: block;
  margin: 0;
  padding: 8px 14px;
  border: 1px solid #e5e5e5;
  border-top-width: 0;
  color: #0088cc;
}
.bs-docs-sidenav > li > a:hover,
.bs-docs-sidenav > li > span:hover {
  background: #f1faff;
}
.bs-docs-sidenav > li > a i.icon-info-sign,
.bs-docs-sidenav > li > span i.icon-info-sign {
  color: #ea0001;
  font-size: 16px;
}
.bs-docs-sidenav > li > span {
  color: #333;
}
.bs-docs-sidenav > .active > a,
.bs-docs-sidenav > .active > span {
  font-weight: bold;
  position: relative;
  color: #0088cc;
  background: #f1faff;
  z-index: 2;
  padding: 9px 15px;
  text-shadow: 0 1px 0 rgba(0, 0, 0, 0.15);
}
.bs-docs-sidenav > .active > a:hover,
.bs-docs-sidenav > .active > span:hover {
  background: #f1faff;
  color: #0088cc;
}
.bs-docs-sidenav > .active > a:after,
.bs-docs-sidenav > .active > span:after {
  border-bottom: 10px solid transparent;
  border-left: 10px solid #f1faff;
  border-top: 10px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
  right: -9px;
  top: 9px;
}
.bs-docs-sidenav > .active > a:before,
.bs-docs-sidenav > .active > span:before {
  border-bottom: 11px solid transparent;
  border-left: 11px solid #ccc;
  border-top: 11px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
  right: -10px;
  top: 8px;
}
.fixed-actions {
  margin-bottom: 180px;
}
.fixed-actions .fixed-actions-group {
  margin: 0;
  z-index: 1010;
  position: fixed;
  bottom: 0;
  left: 0;
  width: 100%;
}
.fixed-actions .form-actions {
  margin: 0;
  background: #2a2a2a;
}
.well-stacked .well {
  margin-bottom: 0;
  border-top-width: 0;
}
.well-stacked .well:first-child {
  border-top-width: 1px;
}
/* Changes for wysihtml5 */
textarea {
  width: 500px;
  height: 400px;
}
.modal > form {
  margin-bottom: 0;
}
.wysihtml5-toolbar {
  *zoom: 1;
}
.wysihtml5-toolbar:before,
.wysihtml5-toolbar:after {
  display: table;
  content: "";
}
.wysihtml5-toolbar:after {
  clear: both;
}
textarea.plain {
  font-family: monospace;
}
/* css for timepicker */
.ui-timepicker-div .ui-widget-header {
  margin-bottom: 8px;
}
.ui-timepicker-div dl {
  text-align: left;
}
.ui-timepicker-div dl dt {
  height: 25px;
  margin-bottom: -25px;
}
.ui-timepicker-div dl dd {
  margin: 0 10px 10px 65px;
}
.ui-timepicker-div td {
  font-size: 90%;
}
.ui-tpicker-grid-label {
  background: none;
  border: none;
  margin: 0;
  padding: 0;
}
.ui-timepicker-rtl {
  direction: rtl;
}
.ui-timepicker-rtl dl {
  text-align: right;
}
.ui-timepicker-rtl dl dd {
  margin: 0 65px 10px 10px;
}
@media (max-width: 1300px) {
  div[data-spy="affix"] {
    width: 200px;
  }
  .navbar-primary .nav > li a:before {
    display: none;
  }
  table .btn {
    padding: 3px 9px;
    font-size: 11px;
    line-height: 16px;
  }
}
@media (max-width: 979px) {
  .affix {
    position: static;
  }
  div[data-spy="affix"] {
    width: 100%;
    margin-bottom: 18px;
  }
  .navbar-primary .nav > li > a {
    border: 0;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
  }
  .navbar-primary .nav > li > a:hover {
    background: #222;
  }
}
@media (max-width: 480px) {
  .nav-collapse {
    -webkit-transform: none;
  }
}
