/*!
 * Bootstrap Responsive v2.1.1
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */


// Responsive.less
// For phone and tablet devices
// -------------------------------------------------------------


// REPEAT VARIABLES & MIXINS
// -------------------------
// Required since we compile the responsive stuff separately

@import "bootstrap/variables.less"; // Modify this for custom colors, font-sizes, etc
@import "bootstrap/mixins.less";
// Oscar variables and mixins
@import "page/mixins.less"; // Kept separtate for bootstrap updates - but should be imported into bootstap mixins.


// RESPONSIVE CLASSES
// ------------------

@import "bootstrap/responsive-utilities.less";


// MEDIA QUERIES
// ------------------

// Large desktops
@import "bootstrap/responsive-1200px-min.less";

// Tablets to regular desktops
@import "bootstrap/responsive-768px-979px.less";

// Phones to portrait tablets and narrow desktops
@import "bootstrap/responsive-767px-max.less";


// RESPONSIVE NAVBAR
// ------------------

// From 979px and below, show a button to toggle navbar contents

// Overwrite Navbar Variable
// -------------------------
@navbarCollapseWidth:             767px;
@import "bootstrap/responsive-navbar.less";

// OSCAR SPECIFIC MEDIA QUERIES
// -------------------------
@import "page/responsive-767px-max.less";
