{% load i18n %}
<form class="form-{{ style|default:"stacked" }} {{ class }}" method="{{ method|default:"post" }}"
    {% if action %}action="{{ action }}"{% endif %}
    {% if includes_files %}enctype="multipart/form-data"{% endif %}>
    {% if not method == "get" %}{% csrf_token %}{% endif %}
    {% include 'partials/form_fields.html' %}
    <div class="form-actions">
        <button class="btn btn-large btn-primary" type="submit">{% trans "Save" %}</button>
        {% trans "or" %} <a href="#" onclick="history.go(-1);return false" >{% trans "cancel" %}</a>.
    </div>
</form>
