{% extends 'dashboard/layout.html' %}
{% load i18n %}

{% block body_class %}{{ block.super }} reports{% endblock %}
{% block title %}
    {% trans "Reports" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
            <span class="divider">/</span>
        </li>
        <li class="active">{% trans "Reporting Dashboard" %}</li>
    </ul>
{% endblock %}

{% block headertext %}
    {% trans "Reporting dashboard" %}
{% endblock %}

{% block dashboard_content %}
    <div class="table-header">
        <h3><i class="icon-bar-chart icon-large"></i>{% trans "Reporting dashboard" %}</h3>
    </div>
    <div class="well">
        <form method="get" action="." class="form-inline">
            {% include "partials/form_fields_inline.html" with form=form %}
            <span class="control-group">
                <button type="submit" class="btn btn-primary">{% trans "Generate report" %}</button>
            </span>
        </form>
    </div>

    {% if description %}
        <div class="table-header">
            <h3><i class="icon-bar-chart icon-large"></i>{{ description }}</h3>
        </div>
    {% endif %}

    {% block report %}
    {% endblock %}

{% endblock dashboard_content %}
