{% load currency_filters %}
{% load product_tags %}
{% load i18n %}

<h2>{{ block.title }}</h2>

{{ block.description|safe }}

<ol>
    {% for product in block.products.all %}
        <li>{% render_product product %}</li>
    {% endfor %}
</ol>
