{% load i18n %}
{% load product_tags %}

{% block content %}
<section class="well well-blank">
    <div class="sub-header">
        <h2>{{ promotion.name }}</h2>
    </div>

    {{ promotion.description|safe }}

    <ul class="row-fluid">
        {% for product in products %}
        <li class="span3 {% if forloop.counter0|divisibleby:"4" %}no-margin{% endif %}">{% render_product product %}</li>
        {% endfor %}
    </ul>

    {% if block.link_url %}
        <a href="{{ block.link_url }}">{% trans "See more" %}</a>
    {% endif %}
</section>
{% endblock %}
