{% extends "layout_2_col.html" %}
{% load i18n %}

{% block navigation %}
    {% include "partials/nav_primary.html" with expand_dropdown=1 %}
{% endblock %}

{% block header %}{% endblock %}

{% block column_left %}
{% endblock %}

{% block content %}
{% endblock content %}
