{% extends "layout.html" %}
{% load promotion_tags %}

{% comment %}
Keep the same header and footer as the standard layout template but override the 
main content area to split it into a sidebar and a content block
{% endcomment %}
{% block content_wrapper %}
<div class="container-fluid page">
    <div class="page_inner">
        {% block breadcrumbs %}{% endblock %}
        <div class="row-fluid">

            <aside class="sidebar span3">
                {# Render promotions at the top of the left-hand sidebar #}
                <div id="promotions_left">
                    {% for promotion in promotions_left %}
                        {% render_promotion promotion %}
                    {% endfor %}
                </div>
                {% block column_left %}{% endblock %}
            </aside>

            <div class="span9">
                {% block header %}
                <div class="page-header action">
                    <h1>{% block headertext %}{% endblock %}</h1>
                </div>
                {% endblock %}

                {% include "partials/alert_messages.html" %}

                <div id="promotions">
                    {% for promotion in promotions_page %}
                        {% render_promotion promotion %}
                    {% endfor %}
                </div>

                {% block content %}{% endblock %}
            </div>

        </div><!-- /row-fluid -->
    </div><!-- /page_inner -->
</div><!-- /container-fluid -->
{% endblock %}
