{% extends "customer/emails/base.html" %}
{% load i18n %}
{% block body %}{% autoescape off %}
<p>
    {% blocktrans with name=site.name %}
    You're receiving this e-mail because your password has been changed at {{ name }}.
    {% endblocktrans %}
</p>

<p>
{% trans "If it wasn't you who changed it, please reset your password immediately:" %}
http://{{ site.domain }}{{ reset_url }}
</p>

<p>{% trans "Otherwise, you can ignore this email." %}</p>
{% endautoescape %}{% endblock %}
