{% extends 'layout.html' %}
{% load i18n %}

{% block title %}{% trans 'Password reset' %} | {{ block.super }}{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{{ homepage_url }}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans 'Password reset' %}</li>
</ul>
{% endblock %}

{% block content %}

    <div class="sub-header">
        <h2>{% trans "Password reset" %}</h2>
    </div>

    <form id="password_reset_form" action="." method="post">
        {% csrf_token %}
        <p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>
        {% include 'partials/form_fields.html' %}
        <div class="form-actions">
            <button type="submit" class="btn btn-primary btn-large">{% trans 'Send reset email' %}</button>
        </div>
    </form>

{% endblock %}
