{% extends 'dashboard/offers/step_form.html' %}
{% load i18n %}

{% block progress %}
    {% include 'dashboard/offers/progress.html' with step=1 %}
{% endblock %}

{% block submittext %}{% trans "Continue to step 2" %}{% endblock %}
