{% extends 'dashboard/layout.html' %}
{% load i18n %}

{% block body_class %}{{ block.super }} create-page{% endblock %}

{% block title %}
    {% trans "Delete partner" %} | {% trans "Partner management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'dashboard:partner-list' %}">{% trans "Partner management" %}</a>
            <span class="divider">/</span>
        </li>
        <li>
            <a href="{% url 'dashboard:partner-manage' pk=partner.pk %}">{{ partner.name }}</a>
            <span class="divider">/</span>
        </li>
        <li class="active">{% trans "Delete?" %}</li>
    </ul>
{% endblock %}

{% block headertext %}
    {{ partner.name }}
{% endblock %}

{% block dashboard_content %}
    <form action="." method="post">
        {% csrf_token %}
        <p>{% trans "Are you sure you want to delete this partner?" %}</p>
        <div class="form-actions">
            <button class="btn btn-large btn-danger" type="submit">{% trans "Delete" %}</button> {% trans "or" %}
            <a href="{% url 'dashboard:partner-list' %}">{% trans "cancel" %}</a>
        </div>
    </form>
{% endblock dashboard_content %}
