// Re setting margins to the bottom only
h1,
h2,
h3,
h4,
h5,
h6,
p,
form,
.control-group,
.table,
.page-header,
.sub-header {
    margin:0 0 @baseLineHeight;
}
ul,
ol {
    margin-bottom:@baseLineHeight;
}
.page-header,
.sub-header,
.table {
    h1, h2, h3, h4, h5, h6, form {
        margin-bottom:0;
    }
}

// Heading fonts a little smaller
h1, .h1 { font-size: @baseFontSize * 2.15; line-height: @baseLineHeight * 2; } // 30px
h2, .h2 { font-size: @baseFontSize * 1.75; line-height: @baseLineHeight * 2; } // 24px
h3, .h3 { font-size: @baseFontSize * 1.25; line-height: @baseLineHeight * 1.2; } // 18px
h4, .h4 { font-size: @baseFontSize * 1.15; line-height: @baseLineHeight * 1.2; } // 16px
h5, .h5 { font-size: @baseFontSize; line-height: @baseLineHeight; } // 14px

// Page / sub headers consistant
.sub-header {
    padding-bottom: (@baseLineHeight / 2) - 1;
    border-bottom: 1px solid @grayLighter;
}
.page-header {
    h1,h2 {
        font-size: @baseFontSize * 2.14;
        line-height: 40px;
    }
}
// Sub header a little lighter
.sub-header {
    h2,h3,h4 {
        font-size: @baseFontSize * 1.6; // 22px
        line-height: @baseLineHeight * 1.5;
        font-weight:normal;
        color:@grayDark;
    }
}

// Text alignment
.align-right,
.table .align-right,
.table .align-right {
    text-align:right;
}

.align-center,
.table .align-center,
.table .align-center {
    text-align:center;
}
