{% extends "checkout/checkout.html" %}
{% load i18n %}

{% block title %}
    {% trans "Edit address" %} | {{ block.super }}
{% endblock title %}

{% block order_contents %}{% endblock %}
{% block shipping_method %}{% endblock %}
{% block payment_method %}{% endblock %}
{% block payment_details %}{% endblock %}

{% block checkout_nav %}
    {% include 'checkout/nav.html' with step=1 %}
{% endblock %}

{% block checkout_title %}{% trans "Edit address" %}{% endblock %}

{% block shipping_address %}
    <form action="." method="post">
        <div class="well">
            {% csrf_token %}
            {% include "partials/form_fields.html" with form=form %}
            <button type="submit" class="btn btn-large btn-primary">{% trans "Save" %}</button>
            {% trans "or" %} <a href="{% url 'checkout:shipping-address' %}">{% trans "cancel" %}</a>.
        </div>
    </form>
{% endblock shipping_address %}
