{% extends 'layout.html' %}
{% load i18n %}

{% block title %}{% trans 'Password reset complete' %} | {{ block.super }}{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{{ homepage_url }}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans 'Password reset complete' %}</li>
</ul>
{% endblock %}

{% block content %}
    <h1>{% trans 'Password reset complete' %}</h1>
    <p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
    <p><a href="{{ login_url }}" class="btn btn-large btn-primary">{% trans 'Log in' %}</a></p>
{% endblock %}
