{% load i18n %}
{% load product_tags %}

{% with products_sliced=products|slice:":6" %}
    {% if products_sliced %}
        <div class="sub-header">
            <h2>{% trans 'Products you recently viewed' %}</h2>
        </div>

        <ul class="row-fluid">
            {% for product in products_sliced %}
                <li class="span2 {% if forloop.counter0|divisibleby:"6" %}no-margin{% endif %}">{% render_product product %}</li>
            {% endfor %}
        </ul>
    {% endif %}
{% endwith %}
