{% extends 'layout.html' %}
{% load i18n %}

{% block title %}{% trans 'Password reset confirm' %} | {{ block.super }}{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{{ homepage_url }}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans 'Enter new password' %}</li>
</ul>
{% endblock %}

{% block content %}

{% if validlink %}

<h1>{% trans 'Enter new password' %}</h1>

<p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>

<form id="password_reset_form" action="" method="post">
    {% csrf_token %}
    {% include 'partials/form_fields.html' %}
    <div class="form-actions">
        <button class="btn btn-primary btn-large" type="submit">{% trans 'Change my password' %}</button>
    </div>
</form>

{% else %}

<h1>{% trans 'Password reset unsuccessful' %}</h1>

<p>{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>

{% endif %}

{% endblock %}
