{% extends "layout.html" %}
{% load i18n %}

{% block title %}
    {{ flatpage.title}} | {{ block.super }}
{% endblock %}

{% block headertext %}
    {{ flatpage.title }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{{ homepage_url }}">{% trans "Home" %}</a>
            <span class="divider">/</span>
        </li>
        <li class="active">{{ flatpage.title }}</li>
    </ul>
{% endblock %}

{% block content %}
    <article>{{ flatpage.content }}</article>
{% endblock %}
