{% load i18n %}
{% load currency_filters %}

<p>
    {% if basket.is_empty %}
        {% trans "Your basket is now empty" %}
    {% else %}
        {% if basket.is_tax_known %}
            {% trans "Basket total now" %} {{ basket.total_incl_tax|currency:basket.currency }}
        {% else %}
            {% trans "Basket total now" %} {{ basket.total_excl_tax|currency:basket.currency }}
        {% endif %}
    {% endif %}
</p>

{% if include_buttons %}
<p>
    <a href="{% url 'basket:summary' %}" class="btn btn-info">{% trans "View basket" %}</a>
    <a href="{% url 'checkout:index' %}" class="btn btn-info">{% trans "Checkout now" %}</a>
</p>
{% endif %}
