// Oscar FORMS

form {
    .clearfix();
}

// For IE: adds width for selects inside overflow hidden containers
.select-open {
    width:300px!important;
}

// Additional errors
.errorlist {
    margin:0;
    padding:0 0 10px 0;
    color:#B94A48;
    li {
        padding:0 0 5px 0;
        list-style:none;
    }
}

.control-label.required span {
    color: #FF0000;
}
