from . import abstract_models


class Transaction(abstract_models.AbstractTransaction):
    pass


class Source(abstract_models.AbstractSource):
    pass


class SourceType(abstract_models.AbstractSourceType):
    pass


class Bankcard(abstract_models.AbstractBankcard):
    pass
